.. _tractography:

Tractography
------------

Tractography, or computational tract tracing is the process that generates
estimates of the trajectories of long-range white matter bundles. For a
detailed explanation of this process, please refer to a review article by
Jeurissen et al. [Jeurissen2019]_.

The pyAFQ software implements a simplified programming interface to the myriad
methods that are implemented in DIPY. Please refer to the detailed
documentation of the :mod:`AFQ.tractography.tractography` module for details.

.. note::

  Tractography is concerned with the visualization and mapping of white matter
  tracts in the brain, while tractometry involves the quantitative analysis of
  the structural properties of these tracts. Both techniques are valuable in
  understanding the brain's connectivity and can provide insights into various
  neurological conditions and cognitive processes.


References
~~~~~~~~~~~

.. [Jeurissen2019] Jeurissen B, Descoteaux M, Mori S, Leemans A. Diffusion MRI
    fiber tractography of the brain. NMR Biomed. 2019 Apr;32(4):e3785. doi:
    10.1002/nbm.3785. Epub 2017 Sep 25. PMID: 28945294.